@@ -1,4 +1,5 @@
 import pandas as pd
+import numpy as np
 
 def data_format(data):
     try:
@@ -8,6 +9,13 @@ def data_format(data):
     except:
         raise ValueError("Data not compatible with pandas DataFrame format")
 
+def numpy_data_format(data):
+    try:
+        data = np.array(data)
+        return data
+    except:
+        raise ValueError("Data not compatible with numpy Matrix format")
+
 def position_data_format(data):
     try:
         data = pd.DataFrame(data, columns=["lon","lat"])
